pub enum TextWrap {
Normal,
BreakWord,
Anywhere,
}Expand description
How a line may break when a word is wider than its box (overflow-wrap /
word-break). CSS’s default lets a long word overflow rather than break.
Variants
Normal
BreakWord
overflow-wrap: break-word: break inside a word rather than overflow.
Anywhere
word-break: break-all: break anywhere.